ジャンプ先: 概要. 戻り値. フラグ. MEL 例.

概要

iprEngine [-copy string] [-defineTemplate string] [-diagnostics] [-estimatedMemory] [-exists] [-iprImage string] [-motionVectorFile] [-object name] [-region int int int int] [-relatedFiles] [-releaseIprImage] [-resolution] [-scanlineIncrement string] [-showProgressBar boolean] [-startTuning] [-stopTuning] [-underPixel int int] [-update] [-updateDepthOfField] [-updateLightGlow boolean] [-updateMotionBlur boolean] [-updatePort string] [-updateShaderGlow boolean] [-updateShading boolean] [-updateShadowMaps] [-useTemplate string]

iprEngine は、取り消し可能、照会可能、および編集可能です。

iprEngine を作成、または編集するためのコマンド。iprEngine はシェーディング ネットワークへの変更を監視し、自動的に再シェーディングして、最新のイメージを生成するオブジェクトです。

戻り値

string- 作成または修正された IPR エンジン名

照会モードでは、戻り値のタイプは照会されたフラグに基づきます。

フラグ

copy, defineTemplate, diagnostics, estimatedMemory, exists, iprImage, motionVectorFile, object, region, relatedFiles, releaseIprImage, resolution, scanlineIncrement, showProgressBar, startTuning, stopTuning, underPixel, update, updateDepthOfField, updateLightGlow, updateMotionBlur, updatePort, updateShaderGlow, updateShading, updateShadowMaps, useTemplate
ロング ネーム(ショート ネーム) 引数タイプ プロパティ
-copy(-cp) string edit
ディープラスタ ファイルとこれに関連するファイルを新しい位置にコピーします。
-defineTemplate(-dt) string create
他の任意のフラグと引数を解析し、かつ引数で指定したコマンド テンプレートに追加するモードに、コマンドのモードを変更します。 templateName が現在のテンプレートとして設定されていれば、その後コマンドが実行されるたびに、この引数が既定の引数として使用されます。
-diagnostics(-dig) edit
診断が表示されます。
-estimatedMemory(-mem) query
IPR で使用されるメモリの見積もり量を表示します。
-exists(-ex) create
指定したオブジェクトが存在するかどうかを返します。他のフラグは無視されます。
-iprImage(-ipr) string createqueryedit
使用する ipr イメージを指定します。
-motionVectorFile(-mvf) query
IPR で使用されるモーション ベクトル ファイルの名前を返します。
-object(-obj) name createqueryedit
調整されるオブジェクトです。
-region(-r) int int int int createqueryedit
調整する領域の座標です。整数は、左 下 右 上、または x1 y2 x2 y2 の順です。
-relatedFiles(-rel) query
「non-glow-non-blur image」などの関連ファイル、モーション ベクトル ファイル、深度マップ ファイルなどの名前を返します。
-releaseIprImage(-rii) edit
ipr イメージとメモリを解放する必要があります。
-resolution(-res) query
ipr ファイルの幅と高さです。
-scanlineIncrement(-sli) string createqueryedit
走査線の増分をパーセントで指定します。更新される領域の高さが 240 ピクセルで scanlineIncrement が 10%の場合、イメージは 24 走査線を 1 ブロックとしてリフレッシュされます。
-showProgressBar(-spb) boolean createqueryedit
調整中に進捗バーを表示します。
-startTuning(-st) createqueryedit
ipr イメージが指定されているときに、シェーディング ネットワークを変更して強制的にイメージを生成します。
-stopTuning(-spt) createqueryedit
調整は終了しますが、ipr イメージは閉じられません。
-underPixel(-un) int int edit
指定したピクセル未満のオブジェクトのリストを取得します。
-update(-u) createedit
強制更新します。
-updateDepthOfField(-udf) createedit
被写界深度を強制的にリフレッシュします。
-updateLightGlow(-ulg) boolean createqueryedit
ライト グローが変更されたときに自動的に更新します。
-updateMotionBlur(-umb) boolean createqueryedit
2.5D モーション ブラーが変更されたときに自動的に更新します。
-updatePort(-up) string createqueryedit
ピクセル値が再計算されたときに更新されるポート番号です(現在は、サポートされていません)。
-updateShaderGlow(-usg) boolean createqueryedit
シェーダ グローが変更されたときに自動的に更新します。
-updateShading(-us) boolean createqueryedit
シェーディングを自動的に更新します。
-updateShadowMaps(-usm) createedit
シャドウ マップを強制的に生成、更新します。
-useTemplate(-ut) string create
コマンドに、現在のものとは異なるコマンド テンプレートを使用するように強制します。

フラグはコマンドの作成モードで表示できます フラグはコマンドの編集モードで表示できます
フラグはコマンドの照会モードで表示できます コマンド内でフラグを複数回使用できます。

MEL 例

// Create a iprEngine and tell it about an already created ipr image.
iprEngine -ipr "iprImages/persp_scene1_ipr.iff"

// Tell the iprEngine about the region to update.
iprEngine -e -region 10 10 100 100 iprEngine1;

// Tell the iprEngine to watch changes and update pixels.
iprEngine -e -startTuning iprEngine1;